::: korapay_client.enums
    handler: python
    options:
      show_root_heading: true
      show_source: true

::: korapay_client.enums.public
    handler: python
    options:
      show_root_heading: true
      show_source: true